@@ -1,5 +1,5 @@
 create_completion(
-    engine = "text-davinci-002",
+    model = "text-davinci-002",
     prompt = "Say this is a test",
     max_tokens = 5
 )
@@ -9,7 +9,7 @@ logit_bias <- list(
     "13" = -100
 )
 create_completion(
-    engine_id = "ada",
+    model = "ada",
     prompt = "Generate a question and an answer",
     n = 4,
     best_of = 4,
