@@ -1,5 +1,5 @@
 create_embedding(
-    model = "text-similarity-babbage-001",
+    model = "text-embedding-ada-002",
     input = c(
         "Ah, it is so boring to write documentation",
         "But examples are really crucial"
