@@ -1,2 +1,2 @@
 voice_sample_ua <- system.file("extdata", "sample-ua.m4a", package = "openai")
-create_translation(file = voice_sample_ua)
+create_translation(file = voice_sample_ua, model = "whisper-1")
